pub struct ZwpInputTimestampsManagerV1 { /* private fields */ }Expand description
context object for high-resolution input timestamps
A global interface used for requesting high-resolution timestamps for input events.
This interface has no events.
Implementations
Sourceimpl ZwpInputTimestampsManagerV1
impl ZwpInputTimestampsManagerV1
Sourcepub fn destroy(&self)
pub fn destroy(&self)
destroy the input timestamps manager object
Informs the server that the client will no longer be using this protocol object. Existing objects created by this object are not affected.
Sourcepub fn get_keyboard_timestamps<U, D: 'static>(
&self,
keyboard: &WlKeyboard,
qh: &QueueHandle<D>,
udata: U,
) -> ZwpInputTimestampsV1
pub fn get_keyboard_timestamps<U, D: 'static>( &self, keyboard: &WlKeyboard, qh: &QueueHandle<D>, udata: U, ) -> ZwpInputTimestampsV1
subscribe to high-resolution keyboard timestamp events
Creates a new input timestamps object that represents a subscription to high-resolution timestamp events for all wl_keyboard events that carry a timestamp.
If the associated wl_keyboard object is invalidated, either through client action (e.g. release) or server-side changes, the input timestamps object becomes inert and the client should destroy it by calling zwp_input_timestamps_v1.destroy.
Sourcepub fn get_pointer_timestamps<U, D: 'static>(
&self,
pointer: &WlPointer,
qh: &QueueHandle<D>,
udata: U,
) -> ZwpInputTimestampsV1
pub fn get_pointer_timestamps<U, D: 'static>( &self, pointer: &WlPointer, qh: &QueueHandle<D>, udata: U, ) -> ZwpInputTimestampsV1
subscribe to high-resolution pointer timestamp events
Creates a new input timestamps object that represents a subscription to high-resolution timestamp events for all wl_pointer events that carry a timestamp.
If the associated wl_pointer object is invalidated, either through client action (e.g. release) or server-side changes, the input timestamps object becomes inert and the client should destroy it by calling zwp_input_timestamps_v1.destroy.
Sourcepub fn get_touch_timestamps<U, D: 'static>(
&self,
touch: &WlTouch,
qh: &QueueHandle<D>,
udata: U,
) -> ZwpInputTimestampsV1
pub fn get_touch_timestamps<U, D: 'static>( &self, touch: &WlTouch, qh: &QueueHandle<D>, udata: U, ) -> ZwpInputTimestampsV1
subscribe to high-resolution touch timestamp events
Creates a new input timestamps object that represents a subscription to high-resolution timestamp events for all wl_touch events that carry a timestamp.
If the associated wl_touch object becomes invalid, either through client action (e.g. release) or server-side changes, the input timestamps object becomes inert and the client should destroy it by calling zwp_input_timestamps_v1.destroy.